@@ -58,6 +58,7 @@ class StandardSqlDataType(proto.Message):
         DATETIME = 21
         GEOGRAPHY = 22
         NUMERIC = 23
+        BIGNUMERIC = 24
         ARRAY = 16
         STRUCT = 17
 
@@ -89,7 +90,7 @@ class StandardSqlField(proto.Message):
 
     name = proto.Field(proto.STRING, number=1)
 
-    type = proto.Field(proto.MESSAGE, number=2, message=StandardSqlDataType,)
+    type = proto.Field(proto.MESSAGE, number=2, message="StandardSqlDataType",)
 
 
 class StandardSqlStructType(proto.Message):
@@ -100,7 +101,7 @@ class StandardSqlStructType(proto.Message):
 
     """
 
-    fields = proto.RepeatedField(proto.MESSAGE, number=1, message=StandardSqlField,)
+    fields = proto.RepeatedField(proto.MESSAGE, number=1, message="StandardSqlField",)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
